Class: Aws::EMRServerless::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::EMRServerless::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-emrserverless/client.rb,
sig/client.rbs
Overview
An API client for EMRServerless. To construct a client, you need to configure a :region and :credentials.
client = Aws::EMRServerless::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CancelJobRunResponseSuccess, _CreateApplicationResponseSuccess, _DeleteApplicationResponseSuccess, _GetApplicationResponseSuccess, _GetDashboardForJobRunResponseSuccess, _GetJobRunResponseSuccess, _GetResourceDashboardResponseSuccess, _GetSessionEndpointResponseSuccess, _GetSessionResponseSuccess, _ListApplicationsResponseSuccess, _ListJobRunAttemptsResponseSuccess, _ListJobRunsResponseSuccess, _ListSessionsResponseSuccess, _ListTagsForResourceResponseSuccess, _StartApplicationResponseSuccess, _StartJobRunResponseSuccess, _StartSessionResponseSuccess, _StopApplicationResponseSuccess, _TagResourceResponseSuccess, _TerminateSessionResponseSuccess, _UntagResourceResponseSuccess, _UpdateApplicationResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_job_run(params = {}) ⇒ Types::CancelJobRunResponse
Cancels a job run.
-
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates an application.
-
#delete_application(params = {}) ⇒ Struct
Deletes an application.
-
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Displays detailed information about a specified application.
-
#get_dashboard_for_job_run(params = {}) ⇒ Types::GetDashboardForJobRunResponse
Creates and returns a URL that you can use to access the application UIs for a job run.
-
#get_job_run(params = {}) ⇒ Types::GetJobRunResponse
Displays detailed information about a job run.
-
#get_resource_dashboard(params = {}) ⇒ Types::GetResourceDashboardResponse
Returns a URL that you can use to access the application UIs for a specified resource, such as a session.
-
#get_session(params = {}) ⇒ Types::GetSessionResponse
Displays detailed information about a session.
-
#get_session_endpoint(params = {}) ⇒ Types::GetSessionEndpointResponse
Returns the session endpoint URL and a time-limited authentication token for the specified session.
-
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists applications based on a set of parameters.
-
#list_job_run_attempts(params = {}) ⇒ Types::ListJobRunAttemptsResponse
Lists all attempt of a job run.
-
#list_job_runs(params = {}) ⇒ Types::ListJobRunsResponse
Lists job runs based on a set of parameters.
-
#list_sessions(params = {}) ⇒ Types::ListSessionsResponse
Lists sessions for the specified application.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags assigned to the resources.
-
#start_application(params = {}) ⇒ Struct
Starts a specified application and initializes initial capacity if configured.
-
#start_job_run(params = {}) ⇒ Types::StartJobRunResponse
Starts a job run.
-
#start_session(params = {}) ⇒ Types::StartSessionResponse
Creates and starts a new session on the specified application.
-
#stop_application(params = {}) ⇒ Struct
Stops a specified application and releases initial capacity if configured.
-
#tag_resource(params = {}) ⇒ Struct
Assigns tags to resources.
-
#terminate_session(params = {}) ⇒ Types::TerminateSessionResponse
Terminates the specified session.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from resources.
-
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates a specified application.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2121 2122 2123 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 2121 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2124 2125 2126 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 2124 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 2094 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::EMRServerless') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-emrserverless' context[:gem_version] = '1.70.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_job_run(params = {}) ⇒ Types::CancelJobRunResponse
Cancels a job run.
87 |
# File 'sig/client.rbs', line 87
def cancel_job_run: (
|
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates an application.
101 |
# File 'sig/client.rbs', line 101
def create_application: (
|
#delete_application(params = {}) ⇒ Struct
Deletes an application. An application has to be in a stopped or created state in order to be deleted.
170 |
# File 'sig/client.rbs', line 170
def delete_application: (
|
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Displays detailed information about a specified application.
180 |
# File 'sig/client.rbs', line 180
def get_application: (
|
#get_dashboard_for_job_run(params = {}) ⇒ Types::GetDashboardForJobRunResponse
Creates and returns a URL that you can use to access the application UIs for a job run.
For jobs in a running state, the application UI is a live user interface such as the Spark or Tez web UI. For completed jobs, the application UI is a persistent application user interface such as the Spark History Server or persistent Tez UI.
190 |
# File 'sig/client.rbs', line 190
def get_dashboard_for_job_run: (
|
#get_job_run(params = {}) ⇒ Types::GetJobRunResponse
Displays detailed information about a job run.
203 |
# File 'sig/client.rbs', line 203
def get_job_run: (
|
#get_resource_dashboard(params = {}) ⇒ Types::GetResourceDashboardResponse
Returns a URL that you can use to access the application UIs for a specified resource, such as a session.
For resources in a running state, the application UI is a live user interface such as the Spark web UI. For terminated resources, the application UI is a persistent application user interface such as the Spark History Server.
215 |
# File 'sig/client.rbs', line 215
def get_resource_dashboard: (
|
#get_session(params = {}) ⇒ Types::GetSessionResponse
Displays detailed information about a session.
227 |
# File 'sig/client.rbs', line 227
def get_session: (
|
#get_session_endpoint(params = {}) ⇒ Types::GetSessionEndpointResponse
Returns the session endpoint URL and a time-limited authentication token for the specified session. Use the endpoint and token to connect a client to the session. Call this operation again when the authentication token expires to obtain a new token.
242 |
# File 'sig/client.rbs', line 242
def get_session_endpoint: (
|
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists applications based on a set of parameters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
254 |
# File 'sig/client.rbs', line 254
def list_applications: (
|
#list_job_run_attempts(params = {}) ⇒ Types::ListJobRunAttemptsResponse
Lists all attempt of a job run.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
267 |
# File 'sig/client.rbs', line 267
def list_job_run_attempts: (
|
#list_job_runs(params = {}) ⇒ Types::ListJobRunsResponse
Lists job runs based on a set of parameters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
281 |
# File 'sig/client.rbs', line 281
def list_job_runs: (
|
#list_sessions(params = {}) ⇒ Types::ListSessionsResponse
Lists sessions for the specified application. You can filter sessions by state and creation time.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
298 |
# File 'sig/client.rbs', line 298
def list_sessions: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags assigned to the resources.
313 |
# File 'sig/client.rbs', line 313
def list_tags_for_resource: (
|
#start_application(params = {}) ⇒ Struct
Starts a specified application and initializes initial capacity if configured.
322 |
# File 'sig/client.rbs', line 322
def start_application: (
|
#start_job_run(params = {}) ⇒ Types::StartJobRunResponse
Starts a job run.
334 |
# File 'sig/client.rbs', line 334
def start_job_run: (
|
#start_session(params = {}) ⇒ Types::StartSessionResponse
Creates and starts a new session on the specified application. The
application must be in the STARTED state or have AutoStart
enabled, and have interactive sessions enabled. This operation is
supported for EMR release 7.13.0 and later.
386 |
# File 'sig/client.rbs', line 386
def start_session: (
|
#stop_application(params = {}) ⇒ Struct
Stops a specified application and releases initial capacity if configured. All scheduled and running jobs must be completed or cancelled before stopping an application.
409 |
# File 'sig/client.rbs', line 409
def stop_application: (
|
#tag_resource(params = {}) ⇒ Struct
Assigns tags to resources. A tag is a label that you assign to an Amazon Web Services resource. Each tag consists of a key and an optional value, both of which you define. Tags enable you to categorize your Amazon Web Services resources by attributes such as purpose, owner, or environment. When you have many resources of the same type, you can quickly identify a specific resource based on the tags you've assigned to it.
418 |
# File 'sig/client.rbs', line 418
def tag_resource: (
|
#terminate_session(params = {}) ⇒ Types::TerminateSessionResponse
Terminates the specified session. After you terminate a session, it
enters the TERMINATING state and then the TERMINATED state. You
can still access the Spark History Server for a terminated session
through the GetResourceDashboard operation.
430 |
# File 'sig/client.rbs', line 430
def terminate_session: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from resources.
440 |
# File 'sig/client.rbs', line 440
def untag_resource: (
|
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates a specified application. An application has to be in a stopped or created state in order to be updated.
451 |
# File 'sig/client.rbs', line 451
def update_application: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2114 2115 2116 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 2114 def waiter_names [] end |