Class: Aws::EMRServerless::Types::ApplicationSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emrserverless/types.rb

Overview

The summary of attributes associated with an application.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#architecture ⇒ String

The CPU architecture of an application.

Returns:

  • (String)


210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/aws-sdk-emrserverless/types.rb', line 210

class ApplicationSummary < Struct.new(
  :id,
  :name,
  :arn,
  :release_label,
  :type,
  :state,
  :state_details,
  :created_at,
  :updated_at,
  :architecture)
  SENSITIVE = []
  include Aws::Structure
end

#arn ⇒ String

The ARN of the application.

Returns:

  • (String)


210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/aws-sdk-emrserverless/types.rb', line 210

class ApplicationSummary < Struct.new(
  :id,
  :name,
  :arn,
  :release_label,
  :type,
  :state,
  :state_details,
  :created_at,
  :updated_at,
  :architecture)
  SENSITIVE = []
  include Aws::Structure
end

#created_at ⇒ Time

The date and time when the application was created.

Returns:

  • (Time)


210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/aws-sdk-emrserverless/types.rb', line 210

class ApplicationSummary < Struct.new(
  :id,
  :name,
  :arn,
  :release_label,
  :type,
  :state,
  :state_details,
  :created_at,
  :updated_at,
  :architecture)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The ID of the application.

Returns:

  • (String)


210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/aws-sdk-emrserverless/types.rb', line 210

class ApplicationSummary < Struct.new(
  :id,
  :name,
  :arn,
  :release_label,
  :type,
  :state,
  :state_details,
  :created_at,
  :updated_at,
  :architecture)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the application.

Returns:

  • (String)


210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/aws-sdk-emrserverless/types.rb', line 210

class ApplicationSummary < Struct.new(
  :id,
  :name,
  :arn,
  :release_label,
  :type,
  :state,
  :state_details,
  :created_at,
  :updated_at,
  :architecture)
  SENSITIVE = []
  include Aws::Structure
end

#release_label ⇒ String

The Amazon EMR release associated with the application.

Returns:

  • (String)


210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/aws-sdk-emrserverless/types.rb', line 210

class ApplicationSummary < Struct.new(
  :id,
  :name,
  :arn,
  :release_label,
  :type,
  :state,
  :state_details,
  :created_at,
  :updated_at,
  :architecture)
  SENSITIVE = []
  include Aws::Structure
end

#state ⇒ String

The state of the application.

Returns:

  • (String)


210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/aws-sdk-emrserverless/types.rb', line 210

class ApplicationSummary < Struct.new(
  :id,
  :name,
  :arn,
  :release_label,
  :type,
  :state,
  :state_details,
  :created_at,
  :updated_at,
  :architecture)
  SENSITIVE = []
  include Aws::Structure
end

#state_details ⇒ String

The state details of the application.

Returns:

  • (String)


210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/aws-sdk-emrserverless/types.rb', line 210

class ApplicationSummary < Struct.new(
  :id,
  :name,
  :arn,
  :release_label,
  :type,
  :state,
  :state_details,
  :created_at,
  :updated_at,
  :architecture)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

The type of application, such as Spark or Hive.

Returns:

  • (String)


210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/aws-sdk-emrserverless/types.rb', line 210

class ApplicationSummary < Struct.new(
  :id,
  :name,
  :arn,
  :release_label,
  :type,
  :state,
  :state_details,
  :created_at,
  :updated_at,
  :architecture)
  SENSITIVE = []
  include Aws::Structure
end

#updated_at ⇒ Time

The date and time when the application was last updated.

Returns:

  • (Time)


210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/aws-sdk-emrserverless/types.rb', line 210

class ApplicationSummary < Struct.new(
  :id,
  :name,
  :arn,
  :release_label,
  :type,
  :state,
  :state_details,
  :created_at,
  :updated_at,
  :architecture)
  SENSITIVE = []
  include Aws::Structure
end