Class: Aws::EMRServerless::Types::GetDashboardForJobRunRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMRServerless::Types::GetDashboardForJobRunRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emrserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_system_profile_logs ⇒ Boolean
Allows access to system profile logs for Lake Formation-enabled jobs.
-
#application_id ⇒ String
The ID of the application.
-
#attempt ⇒ Integer
An optimal parameter that indicates the amount of attempts for the job.
-
#job_run_id ⇒ String
The ID of the job run.
Instance Attribute Details
#access_system_profile_logs ⇒ Boolean
Allows access to system profile logs for Lake Formation-enabled jobs. Default is false.
664 665 666 667 668 669 670 671 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 664 class GetDashboardForJobRunRequest < Struct.new( :application_id, :job_run_id, :attempt, :access_system_profile_logs) SENSITIVE = [] include Aws::Structure end |
#application_id ⇒ String
The ID of the application.
664 665 666 667 668 669 670 671 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 664 class GetDashboardForJobRunRequest < Struct.new( :application_id, :job_run_id, :attempt, :access_system_profile_logs) SENSITIVE = [] include Aws::Structure end |
#attempt ⇒ Integer
An optimal parameter that indicates the amount of attempts for the job. If not specified, this value defaults to the attempt of the latest job.
664 665 666 667 668 669 670 671 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 664 class GetDashboardForJobRunRequest < Struct.new( :application_id, :job_run_id, :attempt, :access_system_profile_logs) SENSITIVE = [] include Aws::Structure end |
#job_run_id ⇒ String
The ID of the job run.
664 665 666 667 668 669 670 671 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 664 class GetDashboardForJobRunRequest < Struct.new( :application_id, :job_run_id, :attempt, :access_system_profile_logs) SENSITIVE = [] include Aws::Structure end |