Class: Aws::EMRServerless::Types::GetResourceDashboardRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emrserverless/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_idString

The ID of the application that the resource belongs to.

Returns:

  • (String)


736
737
738
739
740
741
742
# File 'lib/aws-sdk-emrserverless/types.rb', line 736

class GetResourceDashboardRequest < Struct.new(
  :application_id,
  :resource_id,
  :resource_type)
  SENSITIVE = []
  include Aws::Structure
end

#resource_idString

The ID of the resource.

Returns:

  • (String)


736
737
738
739
740
741
742
# File 'lib/aws-sdk-emrserverless/types.rb', line 736

class GetResourceDashboardRequest < Struct.new(
  :application_id,
  :resource_id,
  :resource_type)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The type of resource to access the dashboard for. Currently, only ‘Session` is supported.

Returns:

  • (String)


736
737
738
739
740
741
742
# File 'lib/aws-sdk-emrserverless/types.rb', line 736

class GetResourceDashboardRequest < Struct.new(
  :application_id,
  :resource_id,
  :resource_type)
  SENSITIVE = []
  include Aws::Structure
end