Class: Aws::EMRServerless::Types::GetSessionEndpointRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMRServerless::Types::GetSessionEndpointRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emrserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_id ⇒ String
The ID of the application that the session belongs to.
-
#session_id ⇒ String
The ID of the session.
Instance Attribute Details
#application_id ⇒ String
The ID of the application that the session belongs to.
769 770 771 772 773 774 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 769 class GetSessionEndpointRequest < Struct.new( :application_id, :session_id) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The ID of the session.
769 770 771 772 773 774 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 769 class GetSessionEndpointRequest < Struct.new( :application_id, :session_id) SENSITIVE = [] include Aws::Structure end |