Class: Aws::EMRServerless::Types::GetSessionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMRServerless::Types::GetSessionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emrserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_id ⇒ String
The ID of the application that the session belongs to.
-
#session_id ⇒ String
The ID of the session.
Instance Attribute Details
#application_id ⇒ String
The ID of the application that the session belongs to.
818 819 820 821 822 823 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 818 class GetSessionRequest < Struct.new( :application_id, :session_id) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The ID of the session.
818 819 820 821 822 823 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 818 class GetSessionRequest < Struct.new( :application_id, :session_id) SENSITIVE = [] include Aws::Structure end |