Class: Aws::EMRServerless::Types::IdentityCenterConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMRServerless::Types::IdentityCenterConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emrserverless/types.rb
Overview
The IAM Identity Center Configuration accepts the Identity Center instance parameter required to enable trusted identity propagation. This configuration allows identity propagation between integrated services and the Identity Center instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#identity_center_application_arn ⇒ String
The ARN of the EMR Serverless created IAM Identity Center Application that provides trusted-identity propagation.
-
#identity_center_instance_arn ⇒ String
The ARN of the IAM Identity Center instance.
-
#user_background_sessions_enabled ⇒ Boolean
Enables user background sessions for this application so Livy sessions can continue running after users log out of their interactive notebook or their Identity Center sessions expire.
Instance Attribute Details
#identity_center_application_arn ⇒ String
The ARN of the EMR Serverless created IAM Identity Center Application that provides trusted-identity propagation.
885 886 887 888 889 890 891 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 885 class IdentityCenterConfiguration < Struct.new( :identity_center_instance_arn, :identity_center_application_arn, :user_background_sessions_enabled) SENSITIVE = [] include Aws::Structure end |
#identity_center_instance_arn ⇒ String
The ARN of the IAM Identity Center instance.
885 886 887 888 889 890 891 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 885 class IdentityCenterConfiguration < Struct.new( :identity_center_instance_arn, :identity_center_application_arn, :user_background_sessions_enabled) SENSITIVE = [] include Aws::Structure end |
#user_background_sessions_enabled ⇒ Boolean
Enables user background sessions for this application so Livy sessions can continue running after users log out of their interactive notebook or their Identity Center sessions expire.
885 886 887 888 889 890 891 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 885 class IdentityCenterConfiguration < Struct.new( :identity_center_instance_arn, :identity_center_application_arn, :user_background_sessions_enabled) SENSITIVE = [] include Aws::Structure end |