Class: Aws::EMRServerless::Types::IdentityCenterConfigurationInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emrserverless/types.rb

Overview

The IAM Identity Center Configuration accepts the Identity Center instance parameter required to enable trusted identity propagation. This configuration allows identity propagation between integrated services and the Identity Center instance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#identity_center_instance_arnString

The ARN of the IAM Identity Center instance.

Returns:

  • (String)


910
911
912
913
914
915
# File 'lib/aws-sdk-emrserverless/types.rb', line 910

class IdentityCenterConfigurationInput < Struct.new(
  :identity_center_instance_arn,
  :user_background_sessions_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#user_background_sessions_enabledBoolean

Enables user background sessions for this application so Livy sessions can continue running after users log out of their interactive notebook or their Identity Center sessions expire.

Returns:

  • (Boolean)


910
911
912
913
914
915
# File 'lib/aws-sdk-emrserverless/types.rb', line 910

class IdentityCenterConfigurationInput < Struct.new(
  :identity_center_instance_arn,
  :user_background_sessions_enabled)
  SENSITIVE = []
  include Aws::Structure
end