Class: Aws::EMRServerless::Types::ImageConfigurationInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emrserverless/types.rb

Overview

The image configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_level_digest_resolutionBoolean

Boolean value indicating if the digest resolution is application level or workload level. If true, a custom image URI is resolved at application start time and all workloads submitted will use that image digest. If false, the custom image URI is resolved at the workload submission time.

Returns:

  • (Boolean)


965
966
967
968
969
970
# File 'lib/aws-sdk-emrserverless/types.rb', line 965

class ImageConfigurationInput < Struct.new(
  :image_uri,
  :application_level_digest_resolution)
  SENSITIVE = []
  include Aws::Structure
end

#image_uriString

The URI of an image in the Amazon ECR registry. This field is required when you create a new application. If you leave this field blank in an update, Amazon EMR will remove the image configuration.

Returns:

  • (String)


965
966
967
968
969
970
# File 'lib/aws-sdk-emrserverless/types.rb', line 965

class ImageConfigurationInput < Struct.new(
  :image_uri,
  :application_level_digest_resolution)
  SENSITIVE = []
  include Aws::Structure
end