Class: Aws::EMRServerless::Types::JobRunAttemptSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMRServerless::Types::JobRunAttemptSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emrserverless/types.rb
Overview
The summary of attributes associated with a job run attempt.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_id ⇒ String
The ID of the application the job is running on.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the job run.
-
#attempt ⇒ Integer
The attempt number of the job run execution.
-
#created_at ⇒ Time
The date and time when the job run attempt was created.
-
#created_by ⇒ String
The user who created the job run.
-
#execution_role ⇒ String
The Amazon Resource Name (ARN) of the execution role of the job run..
-
#id ⇒ String
The ID of the job run attempt.
-
#job_created_at ⇒ Time
The date and time of when the job run was created.
-
#mode ⇒ String
The mode of the job run attempt.
-
#name ⇒ String
The name of the job run attempt.
-
#release_label ⇒ String
The Amazon EMR release label of the job run attempt.
-
#state ⇒ String
The state of the job run attempt.
-
#state_details ⇒ String
The state details of the job run attempt.
-
#type ⇒ String
The type of the job run, such as Spark or Hive.
-
#updated_at ⇒ Time
The date and time of when the job run attempt was last updated.
Instance Attribute Details
#application_id ⇒ String
The ID of the application the job is running on.
1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1287 class JobRunAttemptSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :job_created_at, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the job run.
1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1287 class JobRunAttemptSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :job_created_at, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt) SENSITIVE = [] include Aws::Structure end |
#attempt ⇒ Integer
The attempt number of the job run execution.
1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1287 class JobRunAttemptSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :job_created_at, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time when the job run attempt was created.
1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1287 class JobRunAttemptSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :job_created_at, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The user who created the job run.
1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1287 class JobRunAttemptSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :job_created_at, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt) SENSITIVE = [] include Aws::Structure end |
#execution_role ⇒ String
The Amazon Resource Name (ARN) of the execution role of the job run..
1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1287 class JobRunAttemptSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :job_created_at, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the job run attempt.
1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1287 class JobRunAttemptSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :job_created_at, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt) SENSITIVE = [] include Aws::Structure end |
#job_created_at ⇒ Time
The date and time of when the job run was created.
1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1287 class JobRunAttemptSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :job_created_at, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt) SENSITIVE = [] include Aws::Structure end |
#mode ⇒ String
The mode of the job run attempt.
1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1287 class JobRunAttemptSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :job_created_at, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the job run attempt.
1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1287 class JobRunAttemptSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :job_created_at, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt) SENSITIVE = [] include Aws::Structure end |
#release_label ⇒ String
The Amazon EMR release label of the job run attempt.
1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1287 class JobRunAttemptSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :job_created_at, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the job run attempt.
1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1287 class JobRunAttemptSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :job_created_at, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt) SENSITIVE = [] include Aws::Structure end |
#state_details ⇒ String
The state details of the job run attempt.
1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1287 class JobRunAttemptSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :job_created_at, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the job run, such as Spark or Hive.
1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1287 class JobRunAttemptSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :job_created_at, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time of when the job run attempt was last updated.
1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1287 class JobRunAttemptSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :job_created_at, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt) SENSITIVE = [] include Aws::Structure end |