Class: Aws::EMRServerless::Types::JobRunSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emrserverless/types.rb

Overview

The summary of attributes associated with a job run.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_id ⇒ String

The ID of the application the job is running on.

Returns:

  • (String)


1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
# File 'lib/aws-sdk-emrserverless/types.rb', line 1430

class JobRunSummary < Struct.new(
  :application_id,
  :id,
  :name,
  :mode,
  :arn,
  :created_by,
  :created_at,
  :updated_at,
  :execution_role,
  :state,
  :state_details,
  :release_label,
  :type,
  :attempt,
  :attempt_created_at,
  :attempt_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#arn ⇒ String

The ARN of the job run.

Returns:

  • (String)


1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
# File 'lib/aws-sdk-emrserverless/types.rb', line 1430

class JobRunSummary < Struct.new(
  :application_id,
  :id,
  :name,
  :mode,
  :arn,
  :created_by,
  :created_at,
  :updated_at,
  :execution_role,
  :state,
  :state_details,
  :release_label,
  :type,
  :attempt,
  :attempt_created_at,
  :attempt_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#attempt ⇒ Integer

The attempt number of the job run execution.

Returns:

  • (Integer)


1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
# File 'lib/aws-sdk-emrserverless/types.rb', line 1430

class JobRunSummary < Struct.new(
  :application_id,
  :id,
  :name,
  :mode,
  :arn,
  :created_by,
  :created_at,
  :updated_at,
  :execution_role,
  :state,
  :state_details,
  :release_label,
  :type,
  :attempt,
  :attempt_created_at,
  :attempt_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#attempt_created_at ⇒ Time

The date and time of when the job run attempt was created.

Returns:

  • (Time)


1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
# File 'lib/aws-sdk-emrserverless/types.rb', line 1430

class JobRunSummary < Struct.new(
  :application_id,
  :id,
  :name,
  :mode,
  :arn,
  :created_by,
  :created_at,
  :updated_at,
  :execution_role,
  :state,
  :state_details,
  :release_label,
  :type,
  :attempt,
  :attempt_created_at,
  :attempt_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#attempt_updated_at ⇒ Time

The date and time of when the job run attempt was last updated.

Returns:

  • (Time)


1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
# File 'lib/aws-sdk-emrserverless/types.rb', line 1430

class JobRunSummary < Struct.new(
  :application_id,
  :id,
  :name,
  :mode,
  :arn,
  :created_by,
  :created_at,
  :updated_at,
  :execution_role,
  :state,
  :state_details,
  :release_label,
  :type,
  :attempt,
  :attempt_created_at,
  :attempt_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_at ⇒ Time

The date and time when the job run was created.

Returns:

  • (Time)


1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
# File 'lib/aws-sdk-emrserverless/types.rb', line 1430

class JobRunSummary < Struct.new(
  :application_id,
  :id,
  :name,
  :mode,
  :arn,
  :created_by,
  :created_at,
  :updated_at,
  :execution_role,
  :state,
  :state_details,
  :release_label,
  :type,
  :attempt,
  :attempt_created_at,
  :attempt_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_by ⇒ String

The user who created the job run.

Returns:

  • (String)


1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
# File 'lib/aws-sdk-emrserverless/types.rb', line 1430

class JobRunSummary < Struct.new(
  :application_id,
  :id,
  :name,
  :mode,
  :arn,
  :created_by,
  :created_at,
  :updated_at,
  :execution_role,
  :state,
  :state_details,
  :release_label,
  :type,
  :attempt,
  :attempt_created_at,
  :attempt_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role ⇒ String

The execution role ARN of the job run.

Returns:

  • (String)


1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
# File 'lib/aws-sdk-emrserverless/types.rb', line 1430

class JobRunSummary < Struct.new(
  :application_id,
  :id,
  :name,
  :mode,
  :arn,
  :created_by,
  :created_at,
  :updated_at,
  :execution_role,
  :state,
  :state_details,
  :release_label,
  :type,
  :attempt,
  :attempt_created_at,
  :attempt_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The ID of the job run.

Returns:

  • (String)


1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
# File 'lib/aws-sdk-emrserverless/types.rb', line 1430

class JobRunSummary < Struct.new(
  :application_id,
  :id,
  :name,
  :mode,
  :arn,
  :created_by,
  :created_at,
  :updated_at,
  :execution_role,
  :state,
  :state_details,
  :release_label,
  :type,
  :attempt,
  :attempt_created_at,
  :attempt_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#mode ⇒ String

The mode of the job run.

Returns:

  • (String)


1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
# File 'lib/aws-sdk-emrserverless/types.rb', line 1430

class JobRunSummary < Struct.new(
  :application_id,
  :id,
  :name,
  :mode,
  :arn,
  :created_by,
  :created_at,
  :updated_at,
  :execution_role,
  :state,
  :state_details,
  :release_label,
  :type,
  :attempt,
  :attempt_created_at,
  :attempt_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The optional job run name. This doesn't have to be unique.

Returns:

  • (String)


1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
# File 'lib/aws-sdk-emrserverless/types.rb', line 1430

class JobRunSummary < Struct.new(
  :application_id,
  :id,
  :name,
  :mode,
  :arn,
  :created_by,
  :created_at,
  :updated_at,
  :execution_role,
  :state,
  :state_details,
  :release_label,
  :type,
  :attempt,
  :attempt_created_at,
  :attempt_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#release_label ⇒ String

The Amazon EMR release associated with the application your job is running on.

Returns:

  • (String)


1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
# File 'lib/aws-sdk-emrserverless/types.rb', line 1430

class JobRunSummary < Struct.new(
  :application_id,
  :id,
  :name,
  :mode,
  :arn,
  :created_by,
  :created_at,
  :updated_at,
  :execution_role,
  :state,
  :state_details,
  :release_label,
  :type,
  :attempt,
  :attempt_created_at,
  :attempt_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#state ⇒ String

The state of the job run.

Returns:

  • (String)


1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
# File 'lib/aws-sdk-emrserverless/types.rb', line 1430

class JobRunSummary < Struct.new(
  :application_id,
  :id,
  :name,
  :mode,
  :arn,
  :created_by,
  :created_at,
  :updated_at,
  :execution_role,
  :state,
  :state_details,
  :release_label,
  :type,
  :attempt,
  :attempt_created_at,
  :attempt_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#state_details ⇒ String

The state details of the job run.

Returns:

  • (String)


1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
# File 'lib/aws-sdk-emrserverless/types.rb', line 1430

class JobRunSummary < Struct.new(
  :application_id,
  :id,
  :name,
  :mode,
  :arn,
  :created_by,
  :created_at,
  :updated_at,
  :execution_role,
  :state,
  :state_details,
  :release_label,
  :type,
  :attempt,
  :attempt_created_at,
  :attempt_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

The type of job run, such as Spark or Hive.

Returns:

  • (String)


1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
# File 'lib/aws-sdk-emrserverless/types.rb', line 1430

class JobRunSummary < Struct.new(
  :application_id,
  :id,
  :name,
  :mode,
  :arn,
  :created_by,
  :created_at,
  :updated_at,
  :execution_role,
  :state,
  :state_details,
  :release_label,
  :type,
  :attempt,
  :attempt_created_at,
  :attempt_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_at ⇒ Time

The date and time when the job run was last updated.

Returns:

  • (Time)


1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
# File 'lib/aws-sdk-emrserverless/types.rb', line 1430

class JobRunSummary < Struct.new(
  :application_id,
  :id,
  :name,
  :mode,
  :arn,
  :created_by,
  :created_at,
  :updated_at,
  :execution_role,
  :state,
  :state_details,
  :release_label,
  :type,
  :attempt,
  :attempt_created_at,
  :attempt_updated_at)
  SENSITIVE = []
  include Aws::Structure
end