Class: Aws::EMRServerless::Types::ListJobRunAttemptsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emrserverless/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#job_run_attempts ⇒ Array<Types::JobRunAttemptSummary>

The array of the listed job run attempt objects.

Returns:



1533
1534
1535
1536
1537
1538
# File 'lib/aws-sdk-emrserverless/types.rb', line 1533

class ListJobRunAttemptsResponse < Struct.new(
  :job_run_attempts,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The output displays the token for the next set of application results. This is required for pagination and is available as a response of the previous request.

Returns:

  • (String)


1533
1534
1535
1536
1537
1538
# File 'lib/aws-sdk-emrserverless/types.rb', line 1533

class ListJobRunAttemptsResponse < Struct.new(
  :job_run_attempts,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end