Class: Aws::EMRServerless::Types::ListSessionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emrserverless/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_id ⇒ String

The ID of the application to list sessions for.

Returns:

  • (String)


1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
# File 'lib/aws-sdk-emrserverless/types.rb', line 1631

class ListSessionsRequest < Struct.new(
  :application_id,
  :next_token,
  :max_results,
  :states,
  :created_at_after,
  :created_at_before)
  SENSITIVE = []
  include Aws::Structure
end

#created_at_after ⇒ Time

The lower bound of the option to filter by creation date and time.

Returns:

  • (Time)


1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
# File 'lib/aws-sdk-emrserverless/types.rb', line 1631

class ListSessionsRequest < Struct.new(
  :application_id,
  :next_token,
  :max_results,
  :states,
  :created_at_after,
  :created_at_before)
  SENSITIVE = []
  include Aws::Structure
end

#created_at_before ⇒ Time

The upper bound of the option to filter by creation date and time.

Returns:

  • (Time)


1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
# File 'lib/aws-sdk-emrserverless/types.rb', line 1631

class ListSessionsRequest < Struct.new(
  :application_id,
  :next_token,
  :max_results,
  :states,
  :created_at_after,
  :created_at_before)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of sessions to return in each page of results.

Returns:

  • (Integer)


1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
# File 'lib/aws-sdk-emrserverless/types.rb', line 1631

class ListSessionsRequest < Struct.new(
  :application_id,
  :next_token,
  :max_results,
  :states,
  :created_at_after,
  :created_at_before)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The token for the next set of session results.

Returns:

  • (String)


1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
# File 'lib/aws-sdk-emrserverless/types.rb', line 1631

class ListSessionsRequest < Struct.new(
  :application_id,
  :next_token,
  :max_results,
  :states,
  :created_at_after,
  :created_at_before)
  SENSITIVE = []
  include Aws::Structure
end

#states ⇒ Array<String>

An optional filter for session states. Note that if this filter contains multiple states, the resulting list will be grouped by the state.

Returns:

  • (Array<String>)


1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
# File 'lib/aws-sdk-emrserverless/types.rb', line 1631

class ListSessionsRequest < Struct.new(
  :application_id,
  :next_token,
  :max_results,
  :states,
  :created_at_after,
  :created_at_before)
  SENSITIVE = []
  include Aws::Structure
end