Class: Aws::EMRServerless::Types::ListSessionsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emrserverless/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_token ⇒ String

The output displays the token for the next set of session results. This is required for pagination and is available as a response of the previous request.

Returns:

  • (String)


1654
1655
1656
1657
1658
1659
# File 'lib/aws-sdk-emrserverless/types.rb', line 1654

class ListSessionsResponse < Struct.new(
  :sessions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#sessions ⇒ Array<Types::SessionSummary>

The output lists information about the specified sessions.

Returns:



1654
1655
1656
1657
1658
1659
# File 'lib/aws-sdk-emrserverless/types.rb', line 1654

class ListSessionsResponse < Struct.new(
  :sessions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end