Class: Aws::EMRServerless::Types::SchedulerConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emrserverless/types.rb

Overview

The scheduler configuration for batch and streaming jobs running on this application. Supported with release labels emr-7.0.0 and above.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_concurrent_runsInteger

The maximum concurrent job runs on this application. If scheduler configuration is enabled on your application, the default value is

  1. The valid range is 1 to 1000.

Returns:

  • (Integer)


1898
1899
1900
1901
1902
1903
# File 'lib/aws-sdk-emrserverless/types.rb', line 1898

class SchedulerConfiguration < Struct.new(
  :queue_timeout_minutes,
  :max_concurrent_runs)
  SENSITIVE = []
  include Aws::Structure
end

#queue_timeout_minutesInteger

The maximum duration in minutes for the job in QUEUED state. If scheduler configuration is enabled on your application, the default value is 360 minutes (6 hours). The valid range is from 15 to 720.

Returns:

  • (Integer)


1898
1899
1900
1901
1902
1903
# File 'lib/aws-sdk-emrserverless/types.rb', line 1898

class SchedulerConfiguration < Struct.new(
  :queue_timeout_minutes,
  :max_concurrent_runs)
  SENSITIVE = []
  include Aws::Structure
end