Class: Aws::EMRServerless::Types::SessionSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emrserverless/types.rb

Overview

The summary of attributes associated with a session.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_id ⇒ String

The ID of the application that the session belongs to.

Returns:

  • (String)


2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
# File 'lib/aws-sdk-emrserverless/types.rb', line 2107

class SessionSummary < Struct.new(
  :application_id,
  :session_id,
  :arn,
  :name,
  :state,
  :state_details,
  :release_label,
  :execution_role_arn,
  :created_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#arn ⇒ String

The Amazon Resource Name (ARN) of the session.

Returns:

  • (String)


2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
# File 'lib/aws-sdk-emrserverless/types.rb', line 2107

class SessionSummary < Struct.new(
  :application_id,
  :session_id,
  :arn,
  :name,
  :state,
  :state_details,
  :release_label,
  :execution_role_arn,
  :created_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_at ⇒ Time

The date and time that the session was created.

Returns:

  • (Time)


2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
# File 'lib/aws-sdk-emrserverless/types.rb', line 2107

class SessionSummary < Struct.new(
  :application_id,
  :session_id,
  :arn,
  :name,
  :state,
  :state_details,
  :release_label,
  :execution_role_arn,
  :created_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_by ⇒ String

The IAM principal that created the session.

Returns:

  • (String)


2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
# File 'lib/aws-sdk-emrserverless/types.rb', line 2107

class SessionSummary < Struct.new(
  :application_id,
  :session_id,
  :arn,
  :name,
  :state,
  :state_details,
  :release_label,
  :execution_role_arn,
  :created_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arn ⇒ String

The Amazon Resource Name (ARN) of the execution role for the session.

Returns:

  • (String)


2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
# File 'lib/aws-sdk-emrserverless/types.rb', line 2107

class SessionSummary < Struct.new(
  :application_id,
  :session_id,
  :arn,
  :name,
  :state,
  :state_details,
  :release_label,
  :execution_role_arn,
  :created_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The optional name of the session.

Returns:

  • (String)


2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
# File 'lib/aws-sdk-emrserverless/types.rb', line 2107

class SessionSummary < Struct.new(
  :application_id,
  :session_id,
  :arn,
  :name,
  :state,
  :state_details,
  :release_label,
  :execution_role_arn,
  :created_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#release_label ⇒ String

The Amazon EMR release label associated with the session.

Returns:

  • (String)


2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
# File 'lib/aws-sdk-emrserverless/types.rb', line 2107

class SessionSummary < Struct.new(
  :application_id,
  :session_id,
  :arn,
  :name,
  :state,
  :state_details,
  :release_label,
  :execution_role_arn,
  :created_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#session_id ⇒ String

The ID of the session.

Returns:

  • (String)


2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
# File 'lib/aws-sdk-emrserverless/types.rb', line 2107

class SessionSummary < Struct.new(
  :application_id,
  :session_id,
  :arn,
  :name,
  :state,
  :state_details,
  :release_label,
  :execution_role_arn,
  :created_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#state ⇒ String

The state of the session.

Returns:

  • (String)


2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
# File 'lib/aws-sdk-emrserverless/types.rb', line 2107

class SessionSummary < Struct.new(
  :application_id,
  :session_id,
  :arn,
  :name,
  :state,
  :state_details,
  :release_label,
  :execution_role_arn,
  :created_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#state_details ⇒ String

Additional details about the current state of the session.

Returns:

  • (String)


2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
# File 'lib/aws-sdk-emrserverless/types.rb', line 2107

class SessionSummary < Struct.new(
  :application_id,
  :session_id,
  :arn,
  :name,
  :state,
  :state_details,
  :release_label,
  :execution_role_arn,
  :created_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_at ⇒ Time

The date and time that the session was last updated.

Returns:

  • (Time)


2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
# File 'lib/aws-sdk-emrserverless/types.rb', line 2107

class SessionSummary < Struct.new(
  :application_id,
  :session_id,
  :arn,
  :name,
  :state,
  :state_details,
  :release_label,
  :execution_role_arn,
  :created_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end