Class: Aws::EMRServerless::Types::StartJobRunRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMRServerless::Types::StartJobRunRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emrserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_id ⇒ String
The ID of the application on which to run the job.
-
#client_token ⇒ String
The client idempotency token of the job run to start.
-
#configuration_overrides ⇒ Types::ConfigurationOverrides
The configuration overrides for the job run.
-
#execution_iam_policy ⇒ Types::JobRunExecutionIamPolicy
You can pass an optional IAM policy.
-
#execution_role_arn ⇒ String
The execution role ARN for the job run.
-
#execution_timeout_minutes ⇒ Integer
The maximum duration for the job run to run.
-
#job_driver ⇒ Types::JobDriver
The job driver for the job run.
-
#mode ⇒ String
The mode of the job run when it starts.
-
#name ⇒ String
The optional job run name.
-
#retry_policy ⇒ Types::RetryPolicy
The retry policy when job run starts.
-
#tags ⇒ Hash<String,String>
The tags assigned to the job run.
Instance Attribute Details
#application_id ⇒ String
The ID of the application on which to run the job.
2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2184 class StartJobRunRequest < Struct.new( :application_id, :client_token, :execution_role_arn, :execution_iam_policy, :job_driver, :configuration_overrides, :tags, :execution_timeout_minutes, :name, :mode, :retry_policy) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
The client idempotency token of the job run to start. Its value must be unique for each request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2184 class StartJobRunRequest < Struct.new( :application_id, :client_token, :execution_role_arn, :execution_iam_policy, :job_driver, :configuration_overrides, :tags, :execution_timeout_minutes, :name, :mode, :retry_policy) SENSITIVE = [] include Aws::Structure end |
#configuration_overrides ⇒ Types::ConfigurationOverrides
The configuration overrides for the job run.
2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2184 class StartJobRunRequest < Struct.new( :application_id, :client_token, :execution_role_arn, :execution_iam_policy, :job_driver, :configuration_overrides, :tags, :execution_timeout_minutes, :name, :mode, :retry_policy) SENSITIVE = [] include Aws::Structure end |
#execution_iam_policy ⇒ Types::JobRunExecutionIamPolicy
You can pass an optional IAM policy. The resulting job IAM role permissions will be an intersection of this policy and the policy associated with your job execution role.
2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2184 class StartJobRunRequest < Struct.new( :application_id, :client_token, :execution_role_arn, :execution_iam_policy, :job_driver, :configuration_overrides, :tags, :execution_timeout_minutes, :name, :mode, :retry_policy) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The execution role ARN for the job run.
2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2184 class StartJobRunRequest < Struct.new( :application_id, :client_token, :execution_role_arn, :execution_iam_policy, :job_driver, :configuration_overrides, :tags, :execution_timeout_minutes, :name, :mode, :retry_policy) SENSITIVE = [] include Aws::Structure end |
#execution_timeout_minutes ⇒ Integer
The maximum duration for the job run to run. If the job run runs beyond this duration, it will be automatically cancelled.
2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2184 class StartJobRunRequest < Struct.new( :application_id, :client_token, :execution_role_arn, :execution_iam_policy, :job_driver, :configuration_overrides, :tags, :execution_timeout_minutes, :name, :mode, :retry_policy) SENSITIVE = [] include Aws::Structure end |
#job_driver ⇒ Types::JobDriver
The job driver for the job run.
2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2184 class StartJobRunRequest < Struct.new( :application_id, :client_token, :execution_role_arn, :execution_iam_policy, :job_driver, :configuration_overrides, :tags, :execution_timeout_minutes, :name, :mode, :retry_policy) SENSITIVE = [] include Aws::Structure end |
#mode ⇒ String
The mode of the job run when it starts.
2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2184 class StartJobRunRequest < Struct.new( :application_id, :client_token, :execution_role_arn, :execution_iam_policy, :job_driver, :configuration_overrides, :tags, :execution_timeout_minutes, :name, :mode, :retry_policy) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The optional job run name. This doesn’t have to be unique.
2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2184 class StartJobRunRequest < Struct.new( :application_id, :client_token, :execution_role_arn, :execution_iam_policy, :job_driver, :configuration_overrides, :tags, :execution_timeout_minutes, :name, :mode, :retry_policy) SENSITIVE = [] include Aws::Structure end |
#retry_policy ⇒ Types::RetryPolicy
The retry policy when job run starts.
2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2184 class StartJobRunRequest < Struct.new( :application_id, :client_token, :execution_role_arn, :execution_iam_policy, :job_driver, :configuration_overrides, :tags, :execution_timeout_minutes, :name, :mode, :retry_policy) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags assigned to the job run.
2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2184 class StartJobRunRequest < Struct.new( :application_id, :client_token, :execution_role_arn, :execution_iam_policy, :job_driver, :configuration_overrides, :tags, :execution_timeout_minutes, :name, :mode, :retry_policy) SENSITIVE = [] include Aws::Structure end |