Class: Aws::EMRServerless::Types::TerminateSessionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMRServerless::Types::TerminateSessionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emrserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_id ⇒ String
The ID of the application that the session belongs to.
-
#session_id ⇒ String
The ID of the session to terminate.
Instance Attribute Details
#application_id ⇒ String
The ID of the application that the session belongs to.
2349 2350 2351 2352 2353 2354 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2349 class TerminateSessionRequest < Struct.new( :application_id, :session_id) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The ID of the session to terminate.
2349 2350 2351 2352 2353 2354 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2349 class TerminateSessionRequest < Struct.new( :application_id, :session_id) SENSITIVE = [] include Aws::Structure end |