Class: Aws::EMRServerless::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::EMRServerless::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-emrserverless/client.rb
Overview
An API client for EMRServerless. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::EMRServerless::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_job_run(params = {}) ⇒ Types::CancelJobRunResponse
Cancels a job run.
-
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates an application.
-
#delete_application(params = {}) ⇒ Struct
Deletes an application.
-
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Displays detailed information about a specified application.
-
#get_dashboard_for_job_run(params = {}) ⇒ Types::GetDashboardForJobRunResponse
Creates and returns a URL that you can use to access the application UIs for a job run.
-
#get_job_run(params = {}) ⇒ Types::GetJobRunResponse
Displays detailed information about a job run.
-
#get_resource_dashboard(params = {}) ⇒ Types::GetResourceDashboardResponse
Returns a URL that you can use to access the application UIs for a specified resource, such as a session.
-
#get_session(params = {}) ⇒ Types::GetSessionResponse
Displays detailed information about a session.
-
#get_session_endpoint(params = {}) ⇒ Types::GetSessionEndpointResponse
Returns the session endpoint URL and a time-limited authentication token for the specified session.
-
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists applications based on a set of parameters.
-
#list_job_run_attempts(params = {}) ⇒ Types::ListJobRunAttemptsResponse
Lists all attempt of a job run.
-
#list_job_runs(params = {}) ⇒ Types::ListJobRunsResponse
Lists job runs based on a set of parameters.
-
#list_sessions(params = {}) ⇒ Types::ListSessionsResponse
Lists sessions for the specified application.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags assigned to the resources.
-
#start_application(params = {}) ⇒ Struct
Starts a specified application and initializes initial capacity if configured.
-
#start_job_run(params = {}) ⇒ Types::StartJobRunResponse
Starts a job run.
-
#start_session(params = {}) ⇒ Types::StartSessionResponse
Creates and starts a new session on the specified application.
-
#stop_application(params = {}) ⇒ Struct
Stops a specified application and releases initial capacity if configured.
-
#tag_resource(params = {}) ⇒ Struct
Assigns tags to resources.
-
#terminate_session(params = {}) ⇒ Types::TerminateSessionResponse
Terminates the specified session.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from resources.
-
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates a specified application.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2108 2109 2110 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 2108 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2111 2112 2113 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 2111 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 2081 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::EMRServerless') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-emrserverless' context[:gem_version] = '1.64.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_job_run(params = {}) ⇒ Types::CancelJobRunResponse
Cancels a job run.
513 514 515 516 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 513 def cancel_job_run(params = {}, = {}) req = build_request(:cancel_job_run, params) req.send_request() end |
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates an application.
730 731 732 733 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 730 def create_application(params = {}, = {}) req = build_request(:create_application, params) req.send_request() end |
#delete_application(params = {}) ⇒ Struct
Deletes an application. An application has to be in a stopped or created state in order to be deleted.
753 754 755 756 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 753 def delete_application(params = {}, = {}) req = build_request(:delete_application, params) req.send_request() end |
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Displays detailed information about a specified application.
842 843 844 845 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 842 def get_application(params = {}, = {}) req = build_request(:get_application, params) req.send_request() end |
#get_dashboard_for_job_run(params = {}) ⇒ Types::GetDashboardForJobRunResponse
Creates and returns a URL that you can use to access the application UIs for a job run.
For jobs in a running state, the application UI is a live user interface such as the Spark or Tez web UI. For completed jobs, the application UI is a persistent application user interface such as the Spark History Server or persistent Tez UI.
<note markdown=“1”> The URL is valid for one hour after you generate it. To access the application UI after that hour elapses, you must invoke the API again to generate a new URL.
</note>
897 898 899 900 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 897 def get_dashboard_for_job_run(params = {}, = {}) req = build_request(:get_dashboard_for_job_run, params) req.send_request() end |
#get_job_run(params = {}) ⇒ Types::GetJobRunResponse
Displays detailed information about a job run.
998 999 1000 1001 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 998 def get_job_run(params = {}, = {}) req = build_request(:get_job_run, params) req.send_request() end |
#get_resource_dashboard(params = {}) ⇒ Types::GetResourceDashboardResponse
Returns a URL that you can use to access the application UIs for a specified resource, such as a session.
For resources in a running state, the application UI is a live user interface such as the Spark web UI. For terminated resources, the application UI is a persistent application user interface such as the Spark History Server.
<note markdown=“1”> The URL is valid for one hour after you generate it. To access the application UI after that hour elapses, you must invoke the API again to generate a new URL.
</note>
1047 1048 1049 1050 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 1047 def get_resource_dashboard(params = {}, = {}) req = build_request(:get_resource_dashboard, params) req.send_request() end |
#get_session(params = {}) ⇒ Types::GetSessionResponse
Displays detailed information about a session.
1111 1112 1113 1114 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 1111 def get_session(params = {}, = {}) req = build_request(:get_session, params) req.send_request() end |
#get_session_endpoint(params = {}) ⇒ Types::GetSessionEndpointResponse
Returns the session endpoint URL and a time-limited authentication token for the specified session. Use the endpoint and token to connect a client to the session. Call this operation again when the authentication token expires to obtain a new token.
1154 1155 1156 1157 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 1154 def get_session_endpoint(params = {}, = {}) req = build_request(:get_session_endpoint, params) req.send_request() end |
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists applications based on a set of parameters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1206 1207 1208 1209 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 1206 def list_applications(params = {}, = {}) req = build_request(:list_applications, params) req.send_request() end |
#list_job_run_attempts(params = {}) ⇒ Types::ListJobRunAttemptsResponse
Lists all attempt of a job run.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1265 1266 1267 1268 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 1265 def list_job_run_attempts(params = {}, = {}) req = build_request(:list_job_run_attempts, params) req.send_request() end |
#list_job_runs(params = {}) ⇒ Types::ListJobRunsResponse
Lists job runs based on a set of parameters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1339 1340 1341 1342 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 1339 def list_job_runs(params = {}, = {}) req = build_request(:list_job_runs, params) req.send_request() end |
#list_sessions(params = {}) ⇒ Types::ListSessionsResponse
Lists sessions for the specified application. You can filter sessions by state and creation time.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1405 1406 1407 1408 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 1405 def list_sessions(params = {}, = {}) req = build_request(:list_sessions, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags assigned to the resources.
1436 1437 1438 1439 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 1436 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#start_application(params = {}) ⇒ Struct
Starts a specified application and initializes initial capacity if configured.
1459 1460 1461 1462 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 1459 def start_application(params = {}, = {}) req = build_request(:start_application, params) req.send_request() end |
#start_job_run(params = {}) ⇒ Types::StartJobRunResponse
Starts a job run.
1597 1598 1599 1600 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 1597 def start_job_run(params = {}, = {}) req = build_request(:start_job_run, params) req.send_request() end |
#start_session(params = {}) ⇒ Types::StartSessionResponse
Creates and starts a new session on the specified application. The application must be in the ‘STARTED` state or have `AutoStart` enabled, and have interactive sessions enabled. This operation is supported for EMR release 7.13.0 and later.
1681 1682 1683 1684 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 1681 def start_session(params = {}, = {}) req = build_request(:start_session, params) req.send_request() end |
#stop_application(params = {}) ⇒ Struct
Stops a specified application and releases initial capacity if configured. All scheduled and running jobs must be completed or cancelled before stopping an application.
1705 1706 1707 1708 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 1705 def stop_application(params = {}, = {}) req = build_request(:stop_application, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Assigns tags to resources. A tag is a label that you assign to an Amazon Web Services resource. Each tag consists of a key and an optional value, both of which you define. Tags enable you to categorize your Amazon Web Services resources by attributes such as purpose, owner, or environment. When you have many resources of the same type, you can quickly identify a specific resource based on the tags you’ve assigned to it.
1741 1742 1743 1744 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 1741 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#terminate_session(params = {}) ⇒ Types::TerminateSessionResponse
Terminates the specified session. After you terminate a session, it enters the ‘TERMINATING` state and then the `TERMINATED` state. You can still access the Spark History Server for a terminated session through the `GetResourceDashboard` operation.
1778 1779 1780 1781 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 1778 def terminate_session(params = {}, = {}) req = build_request(:terminate_session, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from resources.
1806 1807 1808 1809 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 1806 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates a specified application. An application has to be in a stopped or created state in order to be updated.
2072 2073 2074 2075 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 2072 def update_application(params = {}, = {}) req = build_request(:update_application, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2101 2102 2103 |
# File 'lib/aws-sdk-emrserverless/client.rb', line 2101 def waiter_names [] end |