Class: Aws::EMRServerless::Types::GetResourceDashboardRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMRServerless::Types::GetResourceDashboardRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emrserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_id ⇒ String
The ID of the application that the resource belongs to.
-
#resource_id ⇒ String
The ID of the resource.
-
#resource_type ⇒ String
The type of resource to access the dashboard for.
Instance Attribute Details
#application_id ⇒ String
The ID of the application that the resource belongs to.
736 737 738 739 740 741 742 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 736 class GetResourceDashboardRequest < Struct.new( :application_id, :resource_id, :resource_type) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The ID of the resource.
736 737 738 739 740 741 742 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 736 class GetResourceDashboardRequest < Struct.new( :application_id, :resource_id, :resource_type) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of resource to access the dashboard for. Currently, only ‘Session` is supported.
736 737 738 739 740 741 742 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 736 class GetResourceDashboardRequest < Struct.new( :application_id, :resource_id, :resource_type) SENSITIVE = [] include Aws::Structure end |