Class: Aws::EMRServerless::Types::IdentityCenterConfigurationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMRServerless::Types::IdentityCenterConfigurationInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emrserverless/types.rb
Overview
The IAM Identity Center Configuration accepts the Identity Center instance parameter required to enable trusted identity propagation. This configuration allows identity propagation between integrated services and the Identity Center instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#identity_center_instance_arn ⇒ String
The ARN of the IAM Identity Center instance.
-
#user_background_sessions_enabled ⇒ Boolean
Enables user background sessions for this application so Livy sessions can continue running after users log out of their interactive notebook or their Identity Center sessions expire.
Instance Attribute Details
#identity_center_instance_arn ⇒ String
The ARN of the IAM Identity Center instance.
908 909 910 911 912 913 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 908 class IdentityCenterConfigurationInput < Struct.new( :identity_center_instance_arn, :user_background_sessions_enabled) SENSITIVE = [] include Aws::Structure end |
#user_background_sessions_enabled ⇒ Boolean
Enables user background sessions for this application so Livy sessions can continue running after users log out of their interactive notebook or their Identity Center sessions expire.
908 909 910 911 912 913 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 908 class IdentityCenterConfigurationInput < Struct.new( :identity_center_instance_arn, :user_background_sessions_enabled) SENSITIVE = [] include Aws::Structure end |