Class: Aws::EMRServerless::Types::JobRun
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMRServerless::Types::JobRun
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emrserverless/types.rb
Overview
Information about a job run. A job run is a unit of work, such as a Spark JAR, Hive query, or SparkSQL query, that you submit to an Amazon EMR Serverless application.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_id ⇒ String
The ID of the application the job is running on.
-
#arn ⇒ String
The execution role ARN of the job run.
-
#attempt ⇒ Integer
The attempt of the job run.
-
#attempt_created_at ⇒ Time
The date and time of when the job run attempt was created.
-
#attempt_updated_at ⇒ Time
The date and time of when the job run attempt was last updated.
-
#billed_resource_utilization ⇒ Types::ResourceUtilization
The aggregate vCPU, memory, and storage that Amazon Web Services has billed for the job run.
-
#configuration_overrides ⇒ Types::ConfigurationOverrides
The configuration settings that are used to override default configuration.
-
#created_at ⇒ Time
The date and time when the job run was created.
-
#created_by ⇒ String
The user who created the job run.
-
#ended_at ⇒ Time
The date and time when the job was terminated.
-
#execution_iam_policy ⇒ Types::JobRunExecutionIamPolicy
Optional IAM policy.
-
#execution_role ⇒ String
The execution role ARN of the job run.
-
#execution_timeout_minutes ⇒ Integer
Returns the job run timeout value from the ‘StartJobRun` call.
-
#job_driver ⇒ Types::JobDriver
The job driver for the job run.
-
#job_run_id ⇒ String
The ID of the job run.
-
#mode ⇒ String
The mode of the job run.
-
#name ⇒ String
The optional job run name.
-
#network_configuration ⇒ Types::NetworkConfiguration
The network configuration for customer VPC connectivity.
-
#queued_duration_milliseconds ⇒ Integer
The total time for a job in the QUEUED state in milliseconds.
-
#release_label ⇒ String
The Amazon EMR release associated with the application your job is running on.
-
#retry_policy ⇒ Types::RetryPolicy
The retry policy of the job run.
-
#started_at ⇒ Time
The date and time when the job moved to the RUNNING state.
-
#state ⇒ String
The state of the job run.
-
#state_details ⇒ String
The state details of the job run.
-
#tags ⇒ Hash<String,String>
The tags assigned to the job run.
-
#total_execution_duration_seconds ⇒ Integer
The job run total execution duration in seconds.
-
#total_resource_utilization ⇒ Types::TotalResourceUtilization
The aggregate vCPU, memory, and storage resources used from the time the job starts to execute, until the time the job terminates, rounded up to the nearest second.
-
#updated_at ⇒ Time
The date and time when the job run was updated.
Instance Attribute Details
#application_id ⇒ String
The ID of the application the job is running on.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1189 class JobRun < Struct.new( :application_id, :job_run_id, :name, :arn, :created_by, :created_at, :updated_at, :execution_role, :execution_iam_policy, :state, :state_details, :release_label, :configuration_overrides, :job_driver, :tags, :total_resource_utilization, :network_configuration, :total_execution_duration_seconds, :execution_timeout_minutes, :billed_resource_utilization, :mode, :retry_policy, :attempt, :attempt_created_at, :attempt_updated_at, :started_at, :ended_at, :queued_duration_milliseconds) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The execution role ARN of the job run.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1189 class JobRun < Struct.new( :application_id, :job_run_id, :name, :arn, :created_by, :created_at, :updated_at, :execution_role, :execution_iam_policy, :state, :state_details, :release_label, :configuration_overrides, :job_driver, :tags, :total_resource_utilization, :network_configuration, :total_execution_duration_seconds, :execution_timeout_minutes, :billed_resource_utilization, :mode, :retry_policy, :attempt, :attempt_created_at, :attempt_updated_at, :started_at, :ended_at, :queued_duration_milliseconds) SENSITIVE = [] include Aws::Structure end |
#attempt ⇒ Integer
The attempt of the job run.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1189 class JobRun < Struct.new( :application_id, :job_run_id, :name, :arn, :created_by, :created_at, :updated_at, :execution_role, :execution_iam_policy, :state, :state_details, :release_label, :configuration_overrides, :job_driver, :tags, :total_resource_utilization, :network_configuration, :total_execution_duration_seconds, :execution_timeout_minutes, :billed_resource_utilization, :mode, :retry_policy, :attempt, :attempt_created_at, :attempt_updated_at, :started_at, :ended_at, :queued_duration_milliseconds) SENSITIVE = [] include Aws::Structure end |
#attempt_created_at ⇒ Time
The date and time of when the job run attempt was created.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1189 class JobRun < Struct.new( :application_id, :job_run_id, :name, :arn, :created_by, :created_at, :updated_at, :execution_role, :execution_iam_policy, :state, :state_details, :release_label, :configuration_overrides, :job_driver, :tags, :total_resource_utilization, :network_configuration, :total_execution_duration_seconds, :execution_timeout_minutes, :billed_resource_utilization, :mode, :retry_policy, :attempt, :attempt_created_at, :attempt_updated_at, :started_at, :ended_at, :queued_duration_milliseconds) SENSITIVE = [] include Aws::Structure end |
#attempt_updated_at ⇒ Time
The date and time of when the job run attempt was last updated.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1189 class JobRun < Struct.new( :application_id, :job_run_id, :name, :arn, :created_by, :created_at, :updated_at, :execution_role, :execution_iam_policy, :state, :state_details, :release_label, :configuration_overrides, :job_driver, :tags, :total_resource_utilization, :network_configuration, :total_execution_duration_seconds, :execution_timeout_minutes, :billed_resource_utilization, :mode, :retry_policy, :attempt, :attempt_created_at, :attempt_updated_at, :started_at, :ended_at, :queued_duration_milliseconds) SENSITIVE = [] include Aws::Structure end |
#billed_resource_utilization ⇒ Types::ResourceUtilization
The aggregate vCPU, memory, and storage that Amazon Web Services has billed for the job run. The billed resources include a 1-minute minimum usage for workers, plus additional storage over 20 GB per worker. Note that billed resources do not include usage for idle pre-initialized workers.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1189 class JobRun < Struct.new( :application_id, :job_run_id, :name, :arn, :created_by, :created_at, :updated_at, :execution_role, :execution_iam_policy, :state, :state_details, :release_label, :configuration_overrides, :job_driver, :tags, :total_resource_utilization, :network_configuration, :total_execution_duration_seconds, :execution_timeout_minutes, :billed_resource_utilization, :mode, :retry_policy, :attempt, :attempt_created_at, :attempt_updated_at, :started_at, :ended_at, :queued_duration_milliseconds) SENSITIVE = [] include Aws::Structure end |
#configuration_overrides ⇒ Types::ConfigurationOverrides
The configuration settings that are used to override default configuration.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1189 class JobRun < Struct.new( :application_id, :job_run_id, :name, :arn, :created_by, :created_at, :updated_at, :execution_role, :execution_iam_policy, :state, :state_details, :release_label, :configuration_overrides, :job_driver, :tags, :total_resource_utilization, :network_configuration, :total_execution_duration_seconds, :execution_timeout_minutes, :billed_resource_utilization, :mode, :retry_policy, :attempt, :attempt_created_at, :attempt_updated_at, :started_at, :ended_at, :queued_duration_milliseconds) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time when the job run was created.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1189 class JobRun < Struct.new( :application_id, :job_run_id, :name, :arn, :created_by, :created_at, :updated_at, :execution_role, :execution_iam_policy, :state, :state_details, :release_label, :configuration_overrides, :job_driver, :tags, :total_resource_utilization, :network_configuration, :total_execution_duration_seconds, :execution_timeout_minutes, :billed_resource_utilization, :mode, :retry_policy, :attempt, :attempt_created_at, :attempt_updated_at, :started_at, :ended_at, :queued_duration_milliseconds) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The user who created the job run.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1189 class JobRun < Struct.new( :application_id, :job_run_id, :name, :arn, :created_by, :created_at, :updated_at, :execution_role, :execution_iam_policy, :state, :state_details, :release_label, :configuration_overrides, :job_driver, :tags, :total_resource_utilization, :network_configuration, :total_execution_duration_seconds, :execution_timeout_minutes, :billed_resource_utilization, :mode, :retry_policy, :attempt, :attempt_created_at, :attempt_updated_at, :started_at, :ended_at, :queued_duration_milliseconds) SENSITIVE = [] include Aws::Structure end |
#ended_at ⇒ Time
The date and time when the job was terminated.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1189 class JobRun < Struct.new( :application_id, :job_run_id, :name, :arn, :created_by, :created_at, :updated_at, :execution_role, :execution_iam_policy, :state, :state_details, :release_label, :configuration_overrides, :job_driver, :tags, :total_resource_utilization, :network_configuration, :total_execution_duration_seconds, :execution_timeout_minutes, :billed_resource_utilization, :mode, :retry_policy, :attempt, :attempt_created_at, :attempt_updated_at, :started_at, :ended_at, :queued_duration_milliseconds) SENSITIVE = [] include Aws::Structure end |
#execution_iam_policy ⇒ Types::JobRunExecutionIamPolicy
Optional IAM policy. The resulting job IAM role permissions will be an intersection of the policies passed and the policy associated with your job execution role.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1189 class JobRun < Struct.new( :application_id, :job_run_id, :name, :arn, :created_by, :created_at, :updated_at, :execution_role, :execution_iam_policy, :state, :state_details, :release_label, :configuration_overrides, :job_driver, :tags, :total_resource_utilization, :network_configuration, :total_execution_duration_seconds, :execution_timeout_minutes, :billed_resource_utilization, :mode, :retry_policy, :attempt, :attempt_created_at, :attempt_updated_at, :started_at, :ended_at, :queued_duration_milliseconds) SENSITIVE = [] include Aws::Structure end |
#execution_role ⇒ String
The execution role ARN of the job run.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1189 class JobRun < Struct.new( :application_id, :job_run_id, :name, :arn, :created_by, :created_at, :updated_at, :execution_role, :execution_iam_policy, :state, :state_details, :release_label, :configuration_overrides, :job_driver, :tags, :total_resource_utilization, :network_configuration, :total_execution_duration_seconds, :execution_timeout_minutes, :billed_resource_utilization, :mode, :retry_policy, :attempt, :attempt_created_at, :attempt_updated_at, :started_at, :ended_at, :queued_duration_milliseconds) SENSITIVE = [] include Aws::Structure end |
#execution_timeout_minutes ⇒ Integer
Returns the job run timeout value from the ‘StartJobRun` call. If no timeout was specified, then it returns the default timeout of 720 minutes.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1189 class JobRun < Struct.new( :application_id, :job_run_id, :name, :arn, :created_by, :created_at, :updated_at, :execution_role, :execution_iam_policy, :state, :state_details, :release_label, :configuration_overrides, :job_driver, :tags, :total_resource_utilization, :network_configuration, :total_execution_duration_seconds, :execution_timeout_minutes, :billed_resource_utilization, :mode, :retry_policy, :attempt, :attempt_created_at, :attempt_updated_at, :started_at, :ended_at, :queued_duration_milliseconds) SENSITIVE = [] include Aws::Structure end |
#job_driver ⇒ Types::JobDriver
The job driver for the job run.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1189 class JobRun < Struct.new( :application_id, :job_run_id, :name, :arn, :created_by, :created_at, :updated_at, :execution_role, :execution_iam_policy, :state, :state_details, :release_label, :configuration_overrides, :job_driver, :tags, :total_resource_utilization, :network_configuration, :total_execution_duration_seconds, :execution_timeout_minutes, :billed_resource_utilization, :mode, :retry_policy, :attempt, :attempt_created_at, :attempt_updated_at, :started_at, :ended_at, :queued_duration_milliseconds) SENSITIVE = [] include Aws::Structure end |
#job_run_id ⇒ String
The ID of the job run.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1189 class JobRun < Struct.new( :application_id, :job_run_id, :name, :arn, :created_by, :created_at, :updated_at, :execution_role, :execution_iam_policy, :state, :state_details, :release_label, :configuration_overrides, :job_driver, :tags, :total_resource_utilization, :network_configuration, :total_execution_duration_seconds, :execution_timeout_minutes, :billed_resource_utilization, :mode, :retry_policy, :attempt, :attempt_created_at, :attempt_updated_at, :started_at, :ended_at, :queued_duration_milliseconds) SENSITIVE = [] include Aws::Structure end |
#mode ⇒ String
The mode of the job run.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1189 class JobRun < Struct.new( :application_id, :job_run_id, :name, :arn, :created_by, :created_at, :updated_at, :execution_role, :execution_iam_policy, :state, :state_details, :release_label, :configuration_overrides, :job_driver, :tags, :total_resource_utilization, :network_configuration, :total_execution_duration_seconds, :execution_timeout_minutes, :billed_resource_utilization, :mode, :retry_policy, :attempt, :attempt_created_at, :attempt_updated_at, :started_at, :ended_at, :queued_duration_milliseconds) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The optional job run name. This doesn’t have to be unique.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1189 class JobRun < Struct.new( :application_id, :job_run_id, :name, :arn, :created_by, :created_at, :updated_at, :execution_role, :execution_iam_policy, :state, :state_details, :release_label, :configuration_overrides, :job_driver, :tags, :total_resource_utilization, :network_configuration, :total_execution_duration_seconds, :execution_timeout_minutes, :billed_resource_utilization, :mode, :retry_policy, :attempt, :attempt_created_at, :attempt_updated_at, :started_at, :ended_at, :queued_duration_milliseconds) SENSITIVE = [] include Aws::Structure end |
#network_configuration ⇒ Types::NetworkConfiguration
The network configuration for customer VPC connectivity.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1189 class JobRun < Struct.new( :application_id, :job_run_id, :name, :arn, :created_by, :created_at, :updated_at, :execution_role, :execution_iam_policy, :state, :state_details, :release_label, :configuration_overrides, :job_driver, :tags, :total_resource_utilization, :network_configuration, :total_execution_duration_seconds, :execution_timeout_minutes, :billed_resource_utilization, :mode, :retry_policy, :attempt, :attempt_created_at, :attempt_updated_at, :started_at, :ended_at, :queued_duration_milliseconds) SENSITIVE = [] include Aws::Structure end |
#queued_duration_milliseconds ⇒ Integer
The total time for a job in the QUEUED state in milliseconds.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1189 class JobRun < Struct.new( :application_id, :job_run_id, :name, :arn, :created_by, :created_at, :updated_at, :execution_role, :execution_iam_policy, :state, :state_details, :release_label, :configuration_overrides, :job_driver, :tags, :total_resource_utilization, :network_configuration, :total_execution_duration_seconds, :execution_timeout_minutes, :billed_resource_utilization, :mode, :retry_policy, :attempt, :attempt_created_at, :attempt_updated_at, :started_at, :ended_at, :queued_duration_milliseconds) SENSITIVE = [] include Aws::Structure end |
#release_label ⇒ String
The Amazon EMR release associated with the application your job is running on.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1189 class JobRun < Struct.new( :application_id, :job_run_id, :name, :arn, :created_by, :created_at, :updated_at, :execution_role, :execution_iam_policy, :state, :state_details, :release_label, :configuration_overrides, :job_driver, :tags, :total_resource_utilization, :network_configuration, :total_execution_duration_seconds, :execution_timeout_minutes, :billed_resource_utilization, :mode, :retry_policy, :attempt, :attempt_created_at, :attempt_updated_at, :started_at, :ended_at, :queued_duration_milliseconds) SENSITIVE = [] include Aws::Structure end |
#retry_policy ⇒ Types::RetryPolicy
The retry policy of the job run.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1189 class JobRun < Struct.new( :application_id, :job_run_id, :name, :arn, :created_by, :created_at, :updated_at, :execution_role, :execution_iam_policy, :state, :state_details, :release_label, :configuration_overrides, :job_driver, :tags, :total_resource_utilization, :network_configuration, :total_execution_duration_seconds, :execution_timeout_minutes, :billed_resource_utilization, :mode, :retry_policy, :attempt, :attempt_created_at, :attempt_updated_at, :started_at, :ended_at, :queued_duration_milliseconds) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The date and time when the job moved to the RUNNING state.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1189 class JobRun < Struct.new( :application_id, :job_run_id, :name, :arn, :created_by, :created_at, :updated_at, :execution_role, :execution_iam_policy, :state, :state_details, :release_label, :configuration_overrides, :job_driver, :tags, :total_resource_utilization, :network_configuration, :total_execution_duration_seconds, :execution_timeout_minutes, :billed_resource_utilization, :mode, :retry_policy, :attempt, :attempt_created_at, :attempt_updated_at, :started_at, :ended_at, :queued_duration_milliseconds) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the job run.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1189 class JobRun < Struct.new( :application_id, :job_run_id, :name, :arn, :created_by, :created_at, :updated_at, :execution_role, :execution_iam_policy, :state, :state_details, :release_label, :configuration_overrides, :job_driver, :tags, :total_resource_utilization, :network_configuration, :total_execution_duration_seconds, :execution_timeout_minutes, :billed_resource_utilization, :mode, :retry_policy, :attempt, :attempt_created_at, :attempt_updated_at, :started_at, :ended_at, :queued_duration_milliseconds) SENSITIVE = [] include Aws::Structure end |
#state_details ⇒ String
The state details of the job run.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1189 class JobRun < Struct.new( :application_id, :job_run_id, :name, :arn, :created_by, :created_at, :updated_at, :execution_role, :execution_iam_policy, :state, :state_details, :release_label, :configuration_overrides, :job_driver, :tags, :total_resource_utilization, :network_configuration, :total_execution_duration_seconds, :execution_timeout_minutes, :billed_resource_utilization, :mode, :retry_policy, :attempt, :attempt_created_at, :attempt_updated_at, :started_at, :ended_at, :queued_duration_milliseconds) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags assigned to the job run.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1189 class JobRun < Struct.new( :application_id, :job_run_id, :name, :arn, :created_by, :created_at, :updated_at, :execution_role, :execution_iam_policy, :state, :state_details, :release_label, :configuration_overrides, :job_driver, :tags, :total_resource_utilization, :network_configuration, :total_execution_duration_seconds, :execution_timeout_minutes, :billed_resource_utilization, :mode, :retry_policy, :attempt, :attempt_created_at, :attempt_updated_at, :started_at, :ended_at, :queued_duration_milliseconds) SENSITIVE = [] include Aws::Structure end |
#total_execution_duration_seconds ⇒ Integer
The job run total execution duration in seconds. This field is only available for job runs in a ‘COMPLETED`, `FAILED`, or `CANCELLED` state.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1189 class JobRun < Struct.new( :application_id, :job_run_id, :name, :arn, :created_by, :created_at, :updated_at, :execution_role, :execution_iam_policy, :state, :state_details, :release_label, :configuration_overrides, :job_driver, :tags, :total_resource_utilization, :network_configuration, :total_execution_duration_seconds, :execution_timeout_minutes, :billed_resource_utilization, :mode, :retry_policy, :attempt, :attempt_created_at, :attempt_updated_at, :started_at, :ended_at, :queued_duration_milliseconds) SENSITIVE = [] include Aws::Structure end |
#total_resource_utilization ⇒ Types::TotalResourceUtilization
The aggregate vCPU, memory, and storage resources used from the time the job starts to execute, until the time the job terminates, rounded up to the nearest second.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1189 class JobRun < Struct.new( :application_id, :job_run_id, :name, :arn, :created_by, :created_at, :updated_at, :execution_role, :execution_iam_policy, :state, :state_details, :release_label, :configuration_overrides, :job_driver, :tags, :total_resource_utilization, :network_configuration, :total_execution_duration_seconds, :execution_timeout_minutes, :billed_resource_utilization, :mode, :retry_policy, :attempt, :attempt_created_at, :attempt_updated_at, :started_at, :ended_at, :queued_duration_milliseconds) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time when the job run was updated.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1189 class JobRun < Struct.new( :application_id, :job_run_id, :name, :arn, :created_by, :created_at, :updated_at, :execution_role, :execution_iam_policy, :state, :state_details, :release_label, :configuration_overrides, :job_driver, :tags, :total_resource_utilization, :network_configuration, :total_execution_duration_seconds, :execution_timeout_minutes, :billed_resource_utilization, :mode, :retry_policy, :attempt, :attempt_created_at, :attempt_updated_at, :started_at, :ended_at, :queued_duration_milliseconds) SENSITIVE = [] include Aws::Structure end |