Class: Aws::EMRServerless::Types::JobRunSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMRServerless::Types::JobRunSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emrserverless/types.rb
Overview
The summary of attributes associated with a job run.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_id ⇒ String
The ID of the application the job is running on.
-
#arn ⇒ String
The ARN of the job run.
-
#attempt ⇒ Integer
The attempt number of the job run execution.
-
#attempt_created_at ⇒ Time
The date and time of when the job run attempt was created.
-
#attempt_updated_at ⇒ Time
The date and time of when the job run attempt was last updated.
-
#created_at ⇒ Time
The date and time when the job run was created.
-
#created_by ⇒ String
The user who created the job run.
-
#execution_role ⇒ String
The execution role ARN of the job run.
-
#id ⇒ String
The ID of the job run.
-
#mode ⇒ String
The mode of the job run.
-
#name ⇒ String
The optional job run name.
-
#release_label ⇒ String
The Amazon EMR release associated with the application your job is running on.
-
#state ⇒ String
The state of the job run.
-
#state_details ⇒ String
The state details of the job run.
-
#type ⇒ String
The type of job run, such as Spark or Hive.
-
#updated_at ⇒ Time
The date and time when the job run was last updated.
Instance Attribute Details
#application_id ⇒ String
The ID of the application the job is running on.
1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1398 class JobRunSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt, :attempt_created_at, :attempt_updated_at) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The ARN of the job run.
1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1398 class JobRunSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt, :attempt_created_at, :attempt_updated_at) SENSITIVE = [] include Aws::Structure end |
#attempt ⇒ Integer
The attempt number of the job run execution.
1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1398 class JobRunSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt, :attempt_created_at, :attempt_updated_at) SENSITIVE = [] include Aws::Structure end |
#attempt_created_at ⇒ Time
The date and time of when the job run attempt was created.
1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1398 class JobRunSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt, :attempt_created_at, :attempt_updated_at) SENSITIVE = [] include Aws::Structure end |
#attempt_updated_at ⇒ Time
The date and time of when the job run attempt was last updated.
1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1398 class JobRunSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt, :attempt_created_at, :attempt_updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time when the job run was created.
1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1398 class JobRunSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt, :attempt_created_at, :attempt_updated_at) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The user who created the job run.
1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1398 class JobRunSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt, :attempt_created_at, :attempt_updated_at) SENSITIVE = [] include Aws::Structure end |
#execution_role ⇒ String
The execution role ARN of the job run.
1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1398 class JobRunSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt, :attempt_created_at, :attempt_updated_at) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the job run.
1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1398 class JobRunSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt, :attempt_created_at, :attempt_updated_at) SENSITIVE = [] include Aws::Structure end |
#mode ⇒ String
The mode of the job run.
1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1398 class JobRunSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt, :attempt_created_at, :attempt_updated_at) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The optional job run name. This doesn’t have to be unique.
1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1398 class JobRunSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt, :attempt_created_at, :attempt_updated_at) SENSITIVE = [] include Aws::Structure end |
#release_label ⇒ String
The Amazon EMR release associated with the application your job is running on.
1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1398 class JobRunSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt, :attempt_created_at, :attempt_updated_at) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the job run.
1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1398 class JobRunSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt, :attempt_created_at, :attempt_updated_at) SENSITIVE = [] include Aws::Structure end |
#state_details ⇒ String
The state details of the job run.
1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1398 class JobRunSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt, :attempt_created_at, :attempt_updated_at) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of job run, such as Spark or Hive.
1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1398 class JobRunSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt, :attempt_created_at, :attempt_updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time when the job run was last updated.
1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1398 class JobRunSummary < Struct.new( :application_id, :id, :name, :mode, :arn, :created_by, :created_at, :updated_at, :execution_role, :state, :state_details, :release_label, :type, :attempt, :attempt_created_at, :attempt_updated_at) SENSITIVE = [] include Aws::Structure end |