Class: Aws::EMRServerless::Types::ListJobRunAttemptsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMRServerless::Types::ListJobRunAttemptsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emrserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_id ⇒ String
The ID of the application for which to list job runs.
-
#job_run_id ⇒ String
The ID of the job run to list.
-
#max_results ⇒ Integer
The maximum number of job run attempts to list.
-
#next_token ⇒ String
The token for the next set of job run attempt results.
Instance Attribute Details
#application_id ⇒ String
The ID of the application for which to list job runs.
1512 1513 1514 1515 1516 1517 1518 1519 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1512 class ListJobRunAttemptsRequest < Struct.new( :application_id, :job_run_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#job_run_id ⇒ String
The ID of the job run to list.
1512 1513 1514 1515 1516 1517 1518 1519 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1512 class ListJobRunAttemptsRequest < Struct.new( :application_id, :job_run_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of job run attempts to list.
1512 1513 1514 1515 1516 1517 1518 1519 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1512 class ListJobRunAttemptsRequest < Struct.new( :application_id, :job_run_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of job run attempt results.
1512 1513 1514 1515 1516 1517 1518 1519 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1512 class ListJobRunAttemptsRequest < Struct.new( :application_id, :job_run_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |