Class: Aws::EMRServerless::Types::ListJobRunsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMRServerless::Types::ListJobRunsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emrserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_id ⇒ String
The ID of the application for which to list the job run.
-
#created_at_after ⇒ Time
The lower bound of the option to filter by creation date and time.
-
#created_at_before ⇒ Time
The upper bound of the option to filter by creation date and time.
-
#max_results ⇒ Integer
The maximum number of job runs that can be listed.
-
#mode ⇒ String
The mode of the job runs to list.
-
#next_token ⇒ String
The token for the next set of job run results.
-
#states ⇒ Array<String>
An optional filter for job run states.
Instance Attribute Details
#application_id ⇒ String
The ID of the application for which to list the job run.
1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1572 class ListJobRunsRequest < Struct.new( :application_id, :next_token, :max_results, :created_at_after, :created_at_before, :states, :mode) SENSITIVE = [] include Aws::Structure end |
#created_at_after ⇒ Time
The lower bound of the option to filter by creation date and time.
1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1572 class ListJobRunsRequest < Struct.new( :application_id, :next_token, :max_results, :created_at_after, :created_at_before, :states, :mode) SENSITIVE = [] include Aws::Structure end |
#created_at_before ⇒ Time
The upper bound of the option to filter by creation date and time.
1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1572 class ListJobRunsRequest < Struct.new( :application_id, :next_token, :max_results, :created_at_after, :created_at_before, :states, :mode) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of job runs that can be listed.
1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1572 class ListJobRunsRequest < Struct.new( :application_id, :next_token, :max_results, :created_at_after, :created_at_before, :states, :mode) SENSITIVE = [] include Aws::Structure end |
#mode ⇒ String
The mode of the job runs to list.
1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1572 class ListJobRunsRequest < Struct.new( :application_id, :next_token, :max_results, :created_at_after, :created_at_before, :states, :mode) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of job run results.
1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1572 class ListJobRunsRequest < Struct.new( :application_id, :next_token, :max_results, :created_at_after, :created_at_before, :states, :mode) SENSITIVE = [] include Aws::Structure end |
#states ⇒ Array<String>
An optional filter for job run states. Note that if this filter contains multiple states, the resulting list will be grouped by the state.
1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1572 class ListJobRunsRequest < Struct.new( :application_id, :next_token, :max_results, :created_at_after, :created_at_before, :states, :mode) SENSITIVE = [] include Aws::Structure end |