Class: Aws::EMRServerless::Types::Session
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMRServerless::Types::Session
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emrserverless/types.rb
Overview
Information about a session, including the session state, configuration, and timestamps.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_id ⇒ String
The ID of the application that the session belongs to.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the session.
-
#billed_resource_utilization ⇒ Types::ResourceUtilization
The aggregate vCPU, memory, and storage that Amazon Web Services has billed for the session.
-
#configuration_overrides ⇒ Types::SessionConfigurationOverrides
The configuration overrides for the session, including runtime configuration properties.
-
#created_at ⇒ Time
The date and time that the session was created.
-
#created_by ⇒ String
The IAM principal that created the session.
-
#ended_at ⇒ Time
The date and time that the session was terminated or failed.
-
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the execution role for the session.
-
#idle_since ⇒ Time
The date and time that the session became idle.
-
#idle_timeout_minutes ⇒ Integer
The idle timeout in minutes for the session.
-
#name ⇒ String
The optional name of the session.
-
#network_configuration ⇒ Types::NetworkConfiguration
The network configuration for customer VPC connectivity for the session.
-
#release_label ⇒ String
The Amazon EMR release label associated with the session.
-
#session_id ⇒ String
The ID of the session.
-
#started_at ⇒ Time
The date and time that the session moved to a running state.
-
#state ⇒ String
The state of the session.
-
#state_details ⇒ String
Additional details about the current state of the session.
-
#tags ⇒ Hash<String,String>
The tags assigned to the session.
-
#total_execution_duration_seconds ⇒ Integer
The total execution duration of the session in seconds.
-
#total_resource_utilization ⇒ Types::TotalResourceUtilization
The aggregate vCPU, memory, and storage resources used from the time the session starts to execute, until the time the session terminates, rounded up to the nearest second.
-
#updated_at ⇒ Time
The date and time that the session was last updated.
Instance Attribute Details
#application_id ⇒ String
The ID of the application that the session belongs to.
1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1985 class Session < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :configuration_overrides, :network_configuration, :idle_timeout_minutes, :tags, :total_resource_utilization, :billed_resource_utilization, :total_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the session.
1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1985 class Session < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :configuration_overrides, :network_configuration, :idle_timeout_minutes, :tags, :total_resource_utilization, :billed_resource_utilization, :total_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#billed_resource_utilization ⇒ Types::ResourceUtilization
The aggregate vCPU, memory, and storage that Amazon Web Services has billed for the session. The billed resources include a 1-minute minimum usage for workers, plus additional storage over 20 GB per worker. Note that billed resources do not include usage for idle pre-initialized workers.
1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1985 class Session < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :configuration_overrides, :network_configuration, :idle_timeout_minutes, :tags, :total_resource_utilization, :billed_resource_utilization, :total_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#configuration_overrides ⇒ Types::SessionConfigurationOverrides
The configuration overrides for the session, including runtime configuration properties.
1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1985 class Session < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :configuration_overrides, :network_configuration, :idle_timeout_minutes, :tags, :total_resource_utilization, :billed_resource_utilization, :total_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time that the session was created.
1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1985 class Session < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :configuration_overrides, :network_configuration, :idle_timeout_minutes, :tags, :total_resource_utilization, :billed_resource_utilization, :total_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The IAM principal that created the session.
1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1985 class Session < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :configuration_overrides, :network_configuration, :idle_timeout_minutes, :tags, :total_resource_utilization, :billed_resource_utilization, :total_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#ended_at ⇒ Time
The date and time that the session was terminated or failed.
1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1985 class Session < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :configuration_overrides, :network_configuration, :idle_timeout_minutes, :tags, :total_resource_utilization, :billed_resource_utilization, :total_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the execution role for the session.
1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1985 class Session < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :configuration_overrides, :network_configuration, :idle_timeout_minutes, :tags, :total_resource_utilization, :billed_resource_utilization, :total_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#idle_since ⇒ Time
The date and time that the session became idle.
1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1985 class Session < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :configuration_overrides, :network_configuration, :idle_timeout_minutes, :tags, :total_resource_utilization, :billed_resource_utilization, :total_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#idle_timeout_minutes ⇒ Integer
The idle timeout in minutes for the session. After the session remains idle for this duration, it is automatically terminated.
1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1985 class Session < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :configuration_overrides, :network_configuration, :idle_timeout_minutes, :tags, :total_resource_utilization, :billed_resource_utilization, :total_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The optional name of the session.
1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1985 class Session < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :configuration_overrides, :network_configuration, :idle_timeout_minutes, :tags, :total_resource_utilization, :billed_resource_utilization, :total_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#network_configuration ⇒ Types::NetworkConfiguration
The network configuration for customer VPC connectivity for the session.
1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1985 class Session < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :configuration_overrides, :network_configuration, :idle_timeout_minutes, :tags, :total_resource_utilization, :billed_resource_utilization, :total_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#release_label ⇒ String
The Amazon EMR release label associated with the session.
1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1985 class Session < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :configuration_overrides, :network_configuration, :idle_timeout_minutes, :tags, :total_resource_utilization, :billed_resource_utilization, :total_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The ID of the session.
1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1985 class Session < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :configuration_overrides, :network_configuration, :idle_timeout_minutes, :tags, :total_resource_utilization, :billed_resource_utilization, :total_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The date and time that the session moved to a running state.
1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1985 class Session < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :configuration_overrides, :network_configuration, :idle_timeout_minutes, :tags, :total_resource_utilization, :billed_resource_utilization, :total_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the session.
1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1985 class Session < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :configuration_overrides, :network_configuration, :idle_timeout_minutes, :tags, :total_resource_utilization, :billed_resource_utilization, :total_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#state_details ⇒ String
Additional details about the current state of the session.
1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1985 class Session < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :configuration_overrides, :network_configuration, :idle_timeout_minutes, :tags, :total_resource_utilization, :billed_resource_utilization, :total_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags assigned to the session.
1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1985 class Session < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :configuration_overrides, :network_configuration, :idle_timeout_minutes, :tags, :total_resource_utilization, :billed_resource_utilization, :total_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#total_execution_duration_seconds ⇒ Integer
The total execution duration of the session in seconds.
1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1985 class Session < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :configuration_overrides, :network_configuration, :idle_timeout_minutes, :tags, :total_resource_utilization, :billed_resource_utilization, :total_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#total_resource_utilization ⇒ Types::TotalResourceUtilization
The aggregate vCPU, memory, and storage resources used from the time the session starts to execute, until the time the session terminates, rounded up to the nearest second.
1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1985 class Session < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :configuration_overrides, :network_configuration, :idle_timeout_minutes, :tags, :total_resource_utilization, :billed_resource_utilization, :total_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time that the session was last updated.
1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 1985 class Session < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :configuration_overrides, :network_configuration, :idle_timeout_minutes, :tags, :total_resource_utilization, :billed_resource_utilization, :total_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |