Class: Aws::EMRServerless::Types::SessionSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emrserverless/types.rb

Overview

The summary of attributes associated with a session.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_idString

The ID of the application that the session belongs to.

Returns:

  • (String)


2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
# File 'lib/aws-sdk-emrserverless/types.rb', line 2075

class SessionSummary < Struct.new(
  :application_id,
  :session_id,
  :arn,
  :name,
  :state,
  :state_details,
  :release_label,
  :execution_role_arn,
  :created_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The Amazon Resource Name (ARN) of the session.

Returns:

  • (String)


2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
# File 'lib/aws-sdk-emrserverless/types.rb', line 2075

class SessionSummary < Struct.new(
  :application_id,
  :session_id,
  :arn,
  :name,
  :state,
  :state_details,
  :release_label,
  :execution_role_arn,
  :created_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time that the session was created.

Returns:

  • (Time)


2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
# File 'lib/aws-sdk-emrserverless/types.rb', line 2075

class SessionSummary < Struct.new(
  :application_id,
  :session_id,
  :arn,
  :name,
  :state,
  :state_details,
  :release_label,
  :execution_role_arn,
  :created_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_byString

The IAM principal that created the session.

Returns:

  • (String)


2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
# File 'lib/aws-sdk-emrserverless/types.rb', line 2075

class SessionSummary < Struct.new(
  :application_id,
  :session_id,
  :arn,
  :name,
  :state,
  :state_details,
  :release_label,
  :execution_role_arn,
  :created_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arnString

The Amazon Resource Name (ARN) of the execution role for the session.

Returns:

  • (String)


2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
# File 'lib/aws-sdk-emrserverless/types.rb', line 2075

class SessionSummary < Struct.new(
  :application_id,
  :session_id,
  :arn,
  :name,
  :state,
  :state_details,
  :release_label,
  :execution_role_arn,
  :created_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The optional name of the session.

Returns:

  • (String)


2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
# File 'lib/aws-sdk-emrserverless/types.rb', line 2075

class SessionSummary < Struct.new(
  :application_id,
  :session_id,
  :arn,
  :name,
  :state,
  :state_details,
  :release_label,
  :execution_role_arn,
  :created_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#release_labelString

The Amazon EMR release label associated with the session.

Returns:

  • (String)


2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
# File 'lib/aws-sdk-emrserverless/types.rb', line 2075

class SessionSummary < Struct.new(
  :application_id,
  :session_id,
  :arn,
  :name,
  :state,
  :state_details,
  :release_label,
  :execution_role_arn,
  :created_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#session_idString

The ID of the session.

Returns:

  • (String)


2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
# File 'lib/aws-sdk-emrserverless/types.rb', line 2075

class SessionSummary < Struct.new(
  :application_id,
  :session_id,
  :arn,
  :name,
  :state,
  :state_details,
  :release_label,
  :execution_role_arn,
  :created_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the session.

Returns:

  • (String)


2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
# File 'lib/aws-sdk-emrserverless/types.rb', line 2075

class SessionSummary < Struct.new(
  :application_id,
  :session_id,
  :arn,
  :name,
  :state,
  :state_details,
  :release_label,
  :execution_role_arn,
  :created_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#state_detailsString

Additional details about the current state of the session.

Returns:

  • (String)


2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
# File 'lib/aws-sdk-emrserverless/types.rb', line 2075

class SessionSummary < Struct.new(
  :application_id,
  :session_id,
  :arn,
  :name,
  :state,
  :state_details,
  :release_label,
  :execution_role_arn,
  :created_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time that the session was last updated.

Returns:

  • (Time)


2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
# File 'lib/aws-sdk-emrserverless/types.rb', line 2075

class SessionSummary < Struct.new(
  :application_id,
  :session_id,
  :arn,
  :name,
  :state,
  :state_details,
  :release_label,
  :execution_role_arn,
  :created_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end