Class: Aws::EMRServerless::Types::SessionSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMRServerless::Types::SessionSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emrserverless/types.rb
Overview
The summary of attributes associated with a session.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_id ⇒ String
The ID of the application that the session belongs to.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the session.
-
#created_at ⇒ Time
The date and time that the session was created.
-
#created_by ⇒ String
The IAM principal that created the session.
-
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the execution role for the session.
-
#name ⇒ String
The optional name of the session.
-
#release_label ⇒ String
The Amazon EMR release label associated with the session.
-
#session_id ⇒ String
The ID of the session.
-
#state ⇒ String
The state of the session.
-
#state_details ⇒ String
Additional details about the current state of the session.
-
#updated_at ⇒ Time
The date and time that the session was last updated.
Instance Attribute Details
#application_id ⇒ String
The ID of the application that the session belongs to.
2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2075 class SessionSummary < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the session.
2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2075 class SessionSummary < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time that the session was created.
2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2075 class SessionSummary < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The IAM principal that created the session.
2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2075 class SessionSummary < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the execution role for the session.
2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2075 class SessionSummary < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The optional name of the session.
2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2075 class SessionSummary < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#release_label ⇒ String
The Amazon EMR release label associated with the session.
2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2075 class SessionSummary < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The ID of the session.
2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2075 class SessionSummary < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the session.
2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2075 class SessionSummary < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#state_details ⇒ String
Additional details about the current state of the session.
2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2075 class SessionSummary < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time that the session was last updated.
2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2075 class SessionSummary < Struct.new( :application_id, :session_id, :arn, :name, :state, :state_details, :release_label, :execution_role_arn, :created_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |