Class: Aws::EMRServerless::Types::StartSessionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMRServerless::Types::StartSessionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emrserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_id ⇒ String
The ID of the application on which to start the session.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#configuration_overrides ⇒ Types::SessionConfigurationOverrides
The configuration overrides for the session.
-
#execution_role_arn ⇒ String
The execution role ARN for the session.
-
#idle_timeout_minutes ⇒ Integer
The idle timeout in minutes for the session.
-
#name ⇒ String
The optional name for the session.
-
#tags ⇒ Hash<String,String>
The tags to assign to the session.
Instance Attribute Details
#application_id ⇒ String
The ID of the application on which to start the session.
2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2264 class StartSessionRequest < Struct.new( :application_id, :client_token, :execution_role_arn, :configuration_overrides, :tags, :idle_timeout_minutes, :name) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you retry a request that completed successfully using the same client token, the server returns the successful response without performing the operation again.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2264 class StartSessionRequest < Struct.new( :application_id, :client_token, :execution_role_arn, :configuration_overrides, :tags, :idle_timeout_minutes, :name) SENSITIVE = [] include Aws::Structure end |
#configuration_overrides ⇒ Types::SessionConfigurationOverrides
The configuration overrides for the session. Only runtime configuration overrides are supported.
2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2264 class StartSessionRequest < Struct.new( :application_id, :client_token, :execution_role_arn, :configuration_overrides, :tags, :idle_timeout_minutes, :name) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The execution role ARN for the session. Amazon EMR Serverless uses this role to access Amazon Web Services resources on your behalf during session execution.
2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2264 class StartSessionRequest < Struct.new( :application_id, :client_token, :execution_role_arn, :configuration_overrides, :tags, :idle_timeout_minutes, :name) SENSITIVE = [] include Aws::Structure end |
#idle_timeout_minutes ⇒ Integer
The idle timeout in minutes for the session. After the session remains idle for this duration, Amazon EMR Serverless automatically terminates it.
2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2264 class StartSessionRequest < Struct.new( :application_id, :client_token, :execution_role_arn, :configuration_overrides, :tags, :idle_timeout_minutes, :name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The optional name for the session.
2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2264 class StartSessionRequest < Struct.new( :application_id, :client_token, :execution_role_arn, :configuration_overrides, :tags, :idle_timeout_minutes, :name) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to assign to the session.
2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-emrserverless/types.rb', line 2264 class StartSessionRequest < Struct.new( :application_id, :client_token, :execution_role_arn, :configuration_overrides, :tags, :idle_timeout_minutes, :name) SENSITIVE = [] include Aws::Structure end |